# CHANGELOG



## v0.0.2 (2024-04-10)

### Fix

* fix: rename package ([`37a8811`](https://github.com/KennethEnevoldsen/retrigen/commit/37a8811ccf6e3a896a0f7bff502d3047a7621ad9))

* fix: Updated package name ([`e3d9a82`](https://github.com/KennethEnevoldsen/retrigen/commit/e3d9a82625370353787bc9f50c9f91568b0a2eb7))

* fix: Updated from cruft template ([`4bf5a1c`](https://github.com/KennethEnevoldsen/retrigen/commit/4bf5a1c894763875d0001485d3e3ea074bd1c143))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/regen ([`248c92c`](https://github.com/KennethEnevoldsen/retrigen/commit/248c92c0c4a0e2b069e97e6d25cc8a5c6ead604c))


## v0.0.1 (2024-04-10)

### Fix

* fix: updated ci to see if package can publish ([`e428271`](https://github.com/KennethEnevoldsen/retrigen/commit/e428271cf7306aeff6b9518888e0a736b10f06d0))

### Unknown

* initial commit ([`bde07d2`](https://github.com/KennethEnevoldsen/retrigen/commit/bde07d254d94c717a2014e8b152ac3fb6e8b1d62))
